@@ -1,11 +1,17 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2019, Maximilian Köhl <mkoehl@cs.uni-saarland.de>
+# Copyright (C) 2019-2020, Maximilian Köhl <koehl@cs.uni-saarland.de>
 
 from __future__ import annotations
 
+from .. import errors
 
-class ModelingError(Exception):
+
+class ModelingError(errors.MombaError):
+    pass
+
+
+class InvalidTypeError(ModelingError):
     pass
 
 
@@ -17,15 +23,7 @@ class NotAVariableError(ModelingError):
     pass
 
 
-class InvalidDeclarationError(ModelingError):
-    pass
-
-
-class UnboundIdentifierError(ModelingError):
-    pass
-
-
-class InvalidTypeError(ModelingError):
+class InvalidOperationError(ModelingError):
     pass
 
 
@@ -33,5 +31,13 @@ class IncompatibleAssignmentsError(ModelingError):
     pass
 
 
-class InvalidOperationError(ModelingError):
+class TypeConstructionError(ModelingError):
+    pass
+
+
+class InvalidDeclarationError(ModelingError):
+    pass
+
+
+class UnboundIdentifierError(ModelingError):
     pass
